#

##

##

###

###

###

    	squishy
    		https://en.wikipedia.org/wiki/Netfilter#

    	objectives

    		[ ] block all ports except

    	important

    		tcpdump
    			tcpdump -i tcp

    				tcpdump -i eth0

    		show the network interfaces
    			[prompt] ip link show

    				lo
    				enp0s31f6
    				br-3c9d77222953
    				docker0
    				hss0
    				veth7075590@if12

    		wireshark